Changelog
---------

1.0.0
~~~~~

* Ignore fixtures from third-party packages

0.3.0
~~~~~

* Add an option to list duplicated fixtures

0.2.2
~~~~~

* Remove docs folder, the README file should be enough
* Fix typo in README

0.2.1
~~~~~

* Fix compatibility with pypy

0.2.0
~~~~~

* Extend support to pytest >= 3.0.0
* Use the verbosity arg to decide to print or not the fixtures docstrings
* Remove the green color when logging unused fixtures
* Minor improvements to README

0.1.0
~~~~~

* First release
